# Release history

#### 1.3.0
Add md files.

#### 1.2.0
Dependency update 1.60.0 - 2.0.0.

#### 1.1.0
Force CDK dependency version update to 1.44.0.

#### 1.0.1
Add permissions to put logs to log group.

#### 1.0.0
Initial project. Not tested. No extensive readme.
